@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Exception;
-$BZ::Client::Exception::VERSION = '1.063';
+$BZ::Client::Exception::VERSION = '1.064';
 sub throw {
     my $class = shift;
     die $class->new(@_)
@@ -48,7 +48,7 @@ BZ::Client::Exception - Exception class thrown by BZ::Client in case of errors.
 
 =head1 VERSION
 
-version 1.063
+version 1.064
 
 =head1 SYNOPSIS
 
@@ -57,11 +57,40 @@ Instead, it throws instances of BZ::Client::Exception.
 
   my $exception = BZ::Client::Exception->new( message     => $message,
                                               http_code   => $httpCode,
-                                              xmlrpc_code => $xmlrpcCode);
+                                              xmlrpc_code => $xmlrpcCode );
 
   BZ::Client::Exception->throw( message     => $message,
                                 http_code   => $httpCode,
-                                xmlrpc_code => $xmlrpcCode);
+                                xmlrpc_code => $xmlrpcCode );
+
+=head1 METHODS
+
+=head2 new
+
+Creates the exception object
+
+=head2 throw
+
+Creates the exception object then dies, so make sure you catch it!
+
+=head2 message
+
+Returns the error message text
+
+=head2 xmlrpc_code
+
+Returns the error code from XMLRPC
+
+=head2 http_code
+
+Returns the http code (200, 404, etc)
+
+=head1 EXAMPLE
+
+ my $client = BZ::Client->new( url => $url, user => $user, password => $pass);
+ $client->login();
+
+ # FIXME need to finish example
 
 =head1 SEE ALSO
 
