@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Test;
-$BZ::Client::Test::VERSION = '1.063';
+$BZ::Client::Test::VERSION = '1.064';
 use BZ::Client();
 
 sub new {
@@ -23,15 +23,16 @@ sub new {
                 if ($@) {
                     die "Failed to load configuration file $f: $@";
                 }
-                if (!$hash  ||  ref($hash) ne 'HASH') {
-                    die "Configuration file $f didn't return a HASH value.";
-                }
+                die "Configuration file $f didn't return a HASH value."
+                    unless ($hash and ref($hash) eq 'HASH');
                 # Create a copy of $hash
-                my %opts = %{ $hash };
-                $self = \%opts;
+                $self = \%{ $hash };
             }
         }
-    } else {
+        # If no file was found, $self becomes and emtpy hashref
+        $self = {} unless ref($self) eq 'HASH';
+    }
+    else {
         $self = { @_ };
     }
     bless($self, ref($class) || $class);
@@ -104,7 +105,7 @@ BZ::Client::Test - Module for writing integration tests
 
 =head1 VERSION
 
-version 1.063
+version 1.064
 
 =head1 SYNOPSIS
 
